==> react-highlight-click-0.1.0.tgz: package/src/__tests__/HighlightClick-test.js <==
jest.dontMock('../HighlightClick');

import React from 'react/addons';

const HighlightClick = require('../HighlightClick');
const TestUtils = React.addons.TestUtils;
const noOp = function() {};

describe('HighlightClick', function() {

  it('should support different tags besides divs', function() {
    let tagName = 'span';

    let reactTree = TestUtils.renderIntoDocument(
      <HighlightClick
        tag={tagName}
        onClick={noOp}
      />
    );

    let el = TestUtils.findRenderedDOMComponentWithTag(reactTree, tagName);

    expect(React.findDOMNode(el).tagName.toLowerCase()).toEqual(tagName.toLowerCase());
  });

  it('should support custom css classes', function() {

    let className = 'testClass';

    let reactTree = TestUtils.renderIntoDocument(
      <HighlightClick
        className={className}
        onClick={noOp}
      />
    );

    let comp = TestUtils.findRenderedDOMComponentWithClass(reactTree, className);

    expect(comp).toBeDefined();
  });

  it('should add a click to the state when clicked', function() {

    let className = 'testClass';

    let reactTree = TestUtils.renderIntoDocument(
      <HighlightClick
        className={className}
        onClick={noOp}
      />
    );

    let el = TestUtils.findRenderedComponentWithType(reactTree, HighlightClick);

    let node = TestUtils.findRenderedDOMComponentWithClass(reactTree, className);

    TestUtils.Simulate.click(node);
    expect(el.state.clicks.length).toEqual(1);

    TestUtils.Simulate.click(node);
    expect(el.state.clicks.length).toEqual(2);

    TestUtils.Simulate.click(node);
    expect(el.state.clicks.length).toEqual(3);
  });

  it('should remove clicks after they timeout', function() {

    let className = 'testClass';
    let timeoutLength = 500;

    let reactTree = TestUtils.renderIntoDocument(
      <HighlightClick
        className={className}
        timeout={timeoutLength}
        onClick={noOp}
      />
    );

    let el = TestUtils.findRenderedComponentWithType(reactTree, HighlightClick);

    let node = TestUtils.findRenderedDOMComponentWithClass(reactTree, className);

    TestUtils.Simulate.click(node);
    expect(el.state.clicks.length).toEqual(1);

    expect(setTimeout.mock.calls.length).toBe(1);
    expect(setTimeout.mock.calls[0][1]).toBe(timeoutLength);

    // Fast Forward
    jest.runAllTimers();

    // Ensure it's empty
    expect(el.state.clicks.length).toEqual(0);

  });

  it('should give each click a unique id', function() {

    let className = 'testClass';

    let reactTree = TestUtils.renderIntoDocument(
      <HighlightClick
        className={className}
        onClick={noOp}
      />
    );

    let comp = TestUtils.findRenderedComponentWithType(reactTree, HighlightClick);

    let node = TestUtils.findRenderedDOMComponentWithClass(reactTree, className);

    TestUtils.Simulate.click(node);
    TestUtils.Simulate.click(node);
    expect(comp.state.clicks.length).toEqual(2);
    expect(comp.state.clicks[0].id).toBeDefined();
    expect(comp.state.clicks[1].id).toBeDefined();
    expect(comp.state.clicks[0].id).not.toEqual(comp.state.clicks[1].id);

  });

});

==> react-highlight-click-0.1.4.tgz: package/src/__tests__/HighlightClick-test.js <==
jest.dontMock('../HighlightClick');

import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';

const HighlightClick = require('../HighlightClick').default;
const noOp = function() {};

describe('HighlightClick', function() {

  it('should support different tags besides divs', function() {
    let tagName = 'span';

    let reactTree = TestUtils.renderIntoDocument(
      <HighlightClick
        tag={tagName}
        onClick={noOp}
      />
    );

    let el = TestUtils.findRenderedDOMComponentWithTag(reactTree, tagName);

    expect(ReactDOM.findDOMNode(el).tagName.toLowerCase()).toEqual(tagName.toLowerCase());
  });

  it('should support custom css classes', function() {

    let className = 'testClass';

    let reactTree = TestUtils.renderIntoDocument(
      <HighlightClick
        className={className}
        onClick={noOp}
      />
    );

    let comp = TestUtils.findRenderedDOMComponentWithClass(reactTree, className);

    expect(comp).toBeDefined();
  });

  it('should add a click to the state when clicked', function() {

    let className = 'testClass';

    let reactTree = TestUtils.renderIntoDocument(
      <HighlightClick
        className={className}
        onClick={noOp}
      />
    );

    let el = TestUtils.findRenderedComponentWithType(reactTree, HighlightClick);

    let node = TestUtils.findRenderedDOMComponentWithClass(reactTree, className);

    TestUtils.Simulate.click(node);
    expect(el.state.clicks.length).toEqual(1);

    TestUtils.Simulate.click(node);
    expect(el.state.clicks.length).toEqual(2);

    TestUtils.Simulate.click(node);
    expect(el.state.clicks.length).toEqual(3);
  });

  it('should remove clicks after they timeout', function() {

    let className = 'testClass';
    let timeoutLength = 500;

    let reactTree = TestUtils.renderIntoDocument(
      <HighlightClick
        className={className}
        timeout={timeoutLength}
        onClick={noOp}
      />
    );

    let el = TestUtils.findRenderedComponentWithType(reactTree, HighlightClick);

    let node = TestUtils.findRenderedDOMComponentWithClass(reactTree, className);

    TestUtils.Simulate.click(node);
    expect(el.state.clicks.length).toEqual(1);

    expect(setTimeout.mock.calls.length).toBe(1);
    expect(setTimeout.mock.calls[0][1]).toBe(timeoutLength);

    // Fast Forward
    jest.runAllTimers();

    // Ensure it's empty
    expect(el.state.clicks.length).toEqual(0);

  });

  it('should give each click a unique id', function() {

    let className = 'testClass';

    let reactTree = TestUtils.renderIntoDocument(
      <HighlightClick
        className={className}
        onClick={noOp}
      />
    );

    let comp = TestUtils.findRenderedComponentWithType(reactTree, HighlightClick);

    let node = TestUtils.findRenderedDOMComponentWithClass(reactTree, className);

    TestUtils.Simulate.click(node);
    TestUtils.Simulate.click(node);
    expect(comp.state.clicks.length).toEqual(2);
    expect(comp.state.clicks[0].id).toBeDefined();
    expect(comp.state.clicks[1].id).toBeDefined();
    expect(comp.state.clicks[0].id).not.toEqual(comp.state.clicks[1].id);

  });

});
